@@ -19,7 +19,7 @@ class Organisation:
         self.grafana_api_model = grafana_api_model
 
     def get_current_organization(self) -> dict:
-        """The method includes a functionality to get the current organization.
+        """The method includes a functionality to get the current organization
 
         Required Permissions:
             Action: orgs:read
@@ -45,7 +45,7 @@ class Organisation:
             return api_call
 
     def get_all_users_by_the_current_organization(self) -> list:
-        """The method includes a functionality to get all users from the current organization.
+        """The method includes a functionality to get all users from the current organization
 
         Required Permissions:
             Action: org.users:read
@@ -71,7 +71,7 @@ class Organisation:
             return api_call
 
     def get_all_users_by_the_current_organization_lookup(self) -> list:
-        """The method includes a functionality to get the lookup information of all users from the current organization.
+        """The method includes a functionality to get the lookup information of all users from the current organization
 
         Required Permissions:
             Action: org.users:read
@@ -97,7 +97,7 @@ class Organisation:
             return api_call
 
     def update_organization_user_role_by_user_id(self, user_id: int, role: str):
-        """The method includes a functionality to update the current organization user by the user id.
+        """The method includes a functionality to update the current organization user by the user id
 
         Args:
             user_id (int): Specify the id of the user
@@ -136,7 +136,7 @@ class Organisation:
             raise ValueError
 
     def delete_organization_user_by_user_id(self, user_id: int):
-        """The method includes a functionality to delete the current organization user by the user id.
+        """The method includes a functionality to delete the current organization user by the user id
 
         Args:
             user_id (int): Specify the id of the user
@@ -173,7 +173,7 @@ class Organisation:
             raise ValueError
 
     def update_current_organization(self, name: str):
-        """The method includes a functionality to update the current organization.
+        """The method includes a functionality to update the current organization
 
         Args:
             name (str): Specify the new name of the current organization
@@ -213,7 +213,7 @@ class Organisation:
     def add_new_user_to_current_organization(
         self, login_or_email: str, role: str
     ) -> int:
-        """The method includes a functionality to add a new user to the current organization.
+        """The method includes a functionality to add a new user to the current organization
 
         Args:
             login_or_email (str): Specify the added user
@@ -253,7 +253,7 @@ class Organisation:
 
 
 class OrganisationAdmin:
-    """The class includes all necessary methods to access the Grafana organisation Admin API endpoint. Be aware that all functionalities inside the class only working with basic authentication (username and password).
+    """The class includes all necessary methods to access the Grafana organisation Admin API endpoint. Be aware that all functionalities inside the class only working with basic authentication (username and password)
 
     Args:
         grafana_api_model (APIModel): Inject a Grafana API model object that includes all necessary values and information
@@ -266,7 +266,7 @@ class OrganisationAdmin:
         self.grafana_api_model = grafana_api_model
 
     def get_organization_by_id(self, org_id: int) -> dict:
-        """The method includes a functionality to get an organization by the id.
+        """The method includes a functionality to get an organization by the id
 
         Args:
             org_id (int): Specify the organization id
@@ -300,7 +300,7 @@ class OrganisationAdmin:
             raise ValueError
 
     def get_organization_by_name(self, name: str) -> dict:
-        """The method includes a functionality to get an organization by the name.
+        """The method includes a functionality to get an organization by the name
 
         Args:
             name (str): Specify the organization name
@@ -335,7 +335,7 @@ class OrganisationAdmin:
             raise ValueError
 
     def get_organizations(self) -> list:
-        """The method includes a functionality to get all organizations.
+        """The method includes a functionality to get all organizations
 
         Required Permissions:
             Action: orgs:read
@@ -362,7 +362,7 @@ class OrganisationAdmin:
             return api_call
 
     def create_organization(self, name: str) -> int:
-        """The method includes a functionality to create an organization.
+        """The method includes a functionality to create an organization
 
         Args:
             name (str): Specify the organization name
@@ -401,7 +401,7 @@ class OrganisationAdmin:
             raise ValueError
 
     def update_organization(self, org_id: int, name: str):
-        """The method includes a functionality to update an organization.
+        """The method includes a functionality to update an organization
 
         Args:
             org_id (int): Specify the organization id
@@ -440,7 +440,7 @@ class OrganisationAdmin:
             raise ValueError
 
     def delete_organization(self, org_id: int):
-        """The method includes a functionality to delete an organization.
+        """The method includes a functionality to delete an organization
 
         Args:
             org_id (int): Specify the organization id
@@ -477,7 +477,7 @@ class OrganisationAdmin:
             raise ValueError
 
     def get_organization_users(self, org_id: int) -> list:
-        """The method includes a functionality to get all organization users specified by the organization id.
+        """The method includes a functionality to get all organization users specified by the organization id
 
         Args:
             org_id (int): Specify the organization id
@@ -511,7 +511,7 @@ class OrganisationAdmin:
             raise ValueError
 
     def add_organization_user(self, org_id: int, login_or_email: str, role: str) -> int:
-        """The method includes a functionality to add a user to an organization.
+        """The method includes a functionality to add a user to an organization
 
         Args:
             org_id (int): Specify the organization id
@@ -551,7 +551,7 @@ class OrganisationAdmin:
             raise ValueError
 
     def update_organization_user(self, org_id: int, user_id: int, role: str):
-        """The method includes a functionality to update organization user specified by the organization id, the user_id and the role.
+        """The method includes a functionality to update organization user specified by the organization id, the user_id and the role
 
         Args:
             org_id (int): Specify the organization id
@@ -591,7 +591,7 @@ class OrganisationAdmin:
             raise ValueError
 
     def delete_organization_user(self, org_id: int, user_id: int):
-        """The method includes a functionality to remove an organization users specified by the organization id and the user id.
+        """The method includes a functionality to remove an organization users specified by the organization id and the user id
 
         Args:
             org_id (int): Specify the organization id
